/*---------------------------------------------------------------------\
|                                                                      |
|                     _     _   _   _     __     _                     |
|                    | |   | | | \_/ |   /  \   | |                    |
|                    | |   | | | |_| |  / /\ \  | |                    |
|                    | |__ | | | | | | / ____ \ | |__                  |
|                    |____||_| |_| |_|/ /    \ \|____|                 |
|                                                                      |
|                             apparmor-control library                 |
|                                                                      |
|                                         (C) SUSE Linux Products GmbH |
\----------------------------------------------------------------------/

  File:       ApparmorControl.hpp

  Author:     Matt Barringer <mbarringer@suse.de>
  Maintainer: Matt Barringer <mbarringer@suse.de>

  Purpose:

/-*/
/**
 * @file   ApparmorControl.hpp
 * @brief  Controls the starting and stopping of AppArmor
 */
#ifndef   LIMAL_APPARMOR_CONTROL_HPP
#define   LIMAL_APPARMOR_CONTROL_HPP

#include <limal/apparmor-control/config.h>
#include <blocxx/String.hpp>
#include <blocxx/COWIntrusiveReference.hpp>
namespace LIMAL_NAMESPACE
{
namespace APPARMOR_CONTROL_NAMESPACE
{

/**
 * @brief AppArmor service control functions
 **/

class ApparmorControl
{
public:
	ApparmorControl();
	~ApparmorControl();


	/**
	 * Returns the path name to the AppArmor init script.
	 * @return The path name to the init script.
	 **/
	blocxx::String getPathToInitScript() const;
	
	/**
	 * Sets the path name to the AppArmor init script.
	 *
	 * @param[in] script The path to the init script.
	 **/
	void setpathToInitScript(const blocxx::String &script);
	
	/**
	 * Returns the path name to the SubDomain status script.
	 * @returns The path name to the init script.
	 */
	blocxx::String getPathToSubdomainStatusScript() const;

	/**
	 * Sets the path name to the SubDomain status script.
	 * @param[in] script The path to the status script.
	 */
	void setPathToSubdomainStatusScript(const blocxx::String &script);

	/**
	 * Calls the rc script's 'start' function.
	 * @return 0 on success, -1 on failure.
	 */
	blocxx::Int32 startAppArmor();

	/**
	 * Calls the rc script's 'stop' function.
	 * @return 0 on success, -1 on failure.
	 */
	blocxx::Int32 stopAppArmor();

	/**
	 * Returns if AppArmor is enabled or not.
	 * @return 0 if AppArmor is enabled, -1 if it is not.
	 */
	blocxx::Int32 isEnabled();

private:
	class Data;
	blocxx::COWIntrusiveReference<Data> m_data;

};

}      // End of APPARMOR_CONTROL_NAMESPACE

namespace Apparmor
{

	using limal::apparmor_control::ApparmorControl;

} 

}      // End of LIMAL_NAMESPACE

#endif // LIMAL_APPARMOR_CONTROL_HPP

