/*---------------------------------------------------------------------\
|                                                                      |
|                     _     _   _   _     __     _                     |
|                    | |   | | | \_/ |   /  \   | |                    |
|                    | |   | | | |_| |  / /\ \  | |                    |
|                    | |__ | | | | | | / ____ \ | |__                  |
|                    |____||_| |_| |_|/ /    \ \|____|                 |
|                                                                      |
|                             apparmor-control library                 |
|                                                                      |
|                                         (C) SUSE Linux Products GmbH |
\----------------------------------------------------------------------/

  File:       config.h

  Author:     Matt Barringer <mbarringer@suse.de>
  Maintainer: Matt Barringer <mbarringer@suse.de>

  Purpose:

/-*/
/**
 * @file config.h
 * This is config file, where we declare the namespace
 * and compilation time definitions, like our version.
 */
#ifndef   apparmor_control_config_h
#define   apparmor_control_config_h

#include <limal/config.h>


/**
 * LiMaL apparmor-control library version.
 */
#ifndef LIMAL_APPARMOR_CONTROL_LIB_VERSION
#define LIMAL_APPARMOR_CONTROL_LIB_VERSION		"1.4.2"
#endif


/**
 * LiMaL apparmor-control API/namespace version.
 */
#ifndef LIMAL_APPARMOR_CONTROL_API_VERSION
#define LIMAL_APPARMOR_CONTROL_API_VERSION		1
#endif


/**
 * LiMaL apparmor-control namespace definition
 * with appended API version number.
 */
#ifndef APPARMOR_CONTROL_NAMESPACE
#define APPARMOR_CONTROL_NAMESPACE \
	LIMAL_DEFINE_NAMESPACE(apparmor_control, LIMAL_APPARMOR_CONTROL_API_VERSION)
#endif /* APPARMOR_CONTROL_NAMESPACE */


/**
 * @namespace limal::apparmor_control
 * The LiMaL apparmor_control namespace is only a alias.
 * The real namespace is defined in the @file config.h
 * file to a namespace with appended API version number.
 */
#ifdef    __cplusplus
namespace LIMAL_NAMESPACE
{
    namespace APPARMOR_CONTROL_NAMESPACE
    {
    }
    namespace apparmor_control = APPARMOR_CONTROL_NAMESPACE;
}
#endif /* __cplusplus */


#ifdef    __cplusplus
extern "C" {
#endif /* __cplusplus */

/**
 * LiMaL apparmor-control lib version number function.
 * @returns library version string
 */
const char * limal_apparmor_control_lib_version();


/**
 * LiMaL apparmor-control API version number function.
 * @returns library API version number
 */
unsigned int limal_apparmor_control_api_version();

#ifdef    __cplusplus
}
#endif /* __cplusplus */


#endif /* apparmor_control_config_h  */

